Task: Simple Questions
=======================
Description: Open-domain QA dataset based on Freebase triples from Bordes et al. '15. 

Link: https://arxiv.org/abs/1506.02075

Tags: #SimpleQuestions, #All, #QA

